﻿//=======================================================================================
//
//  Purpose: Implement the code behind for the NE555 main page.
//
//
//  Copyright (C) 2011 Mark Stevens
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software") to use
//  the Software in a non-commercial environment subject to the following conditions:
//
//  1.  The above copyright notice and this permission notice shall be included in
//      all copies or substantial portions of the Software.
//  2.  The original author shall be acknowledged in any software and documentation
//      including (but not restricted to) books, articles and online posts.
//
//  Use in a commercial environment is subject to the written consent of the author
//  and/or copyright holder.
//
//  The Software, documentation, instructions for use and associated materials
//  are provided "as is" without warranty of any kind express or implied.  The
//  author and copyright holders shall ihn no way be held liable for any claim
//  or damages arising as a result of the use of the software and/or documentation.
//
//=======================================================================================
using System.Net.Sockets;
using System.Windows;
using System.Windows.Controls;
using System.Net;
using System.Text;

namespace NE555Calculator
{
    public partial class MainPage : UserControl
    {
        #region Properties

        /// <summary>
        /// View model for teh NE555 calculator.
        /// </summary>
        private NE555CalculatorViewModel NE555 { get; set; }

        #endregion

        #region Constructor(s)

        /// <summary>
        /// Default constructor.
        /// </summary>
        public MainPage()
        {
            Loaded += new RoutedEventHandler(MainPage_Loaded);
            InitializeComponent();
        }

        #endregion

        #region Events

        /// <summary>
        /// Interface controls have been initialised and we can now start to work with them.
        /// </summary>
        private void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            NE555 = new NE555CalculatorViewModel();
            LayoutRoot.DataContext = NE555;
        }

        /// <summary>
        /// Perform the calculations for the timer.
        /// </summary>
        private void btnCalculate_Click(object sender, RoutedEventArgs e)
        {
            if (NE555.Calculate())
            {
                tiResults.IsSelected = true;
            }
        }

        /// <summary>
        /// Connect to the Netduino.
        /// </summary>
        private void btnConfigure_Click(object sender, RoutedEventArgs e)
        {
            NE555.SendConfiguration();
        }

        /// <summary>
        /// Get the data file from the Netduino.
        /// </summary>
        private void btnGetDataFile_Click(object sender, RoutedEventArgs e)
        {
            NE555.GetDataFile(tbxFileName.Text);
        }

        #endregion
    }
}
